searchNodes=[{"type":"module","title":"CFSync","doc":"CFSync is an Elixir client for Contentful sync API . Features Provides functions to extract field values from Contentful entries JSON payloads. Maps Contenful entries, assets, and links to Elixir structs. Using structs is better for readability, performance and reliability. Works with a single or multiple locales. Maps RichText data to Elixir structs. Keeps a cache of your entries and assets in a ETS table. This allows for fast (way faster than REST API calls) and concurrent reads. Keeps this cache up to date by regularly fetching changes from Contentful sync API Installation Add :cf_sync to your mix.exs dependencies. def deps do [ { :cf_sync , &quot;~&gt; 0.15.0&quot; } , ] end Basic usage # Define your fields mappings, one per content-type defmodule MyApp.PageFields do @behaviour CFSync.Entry.Fields import CFSync.Entry.Extractors defstruct :name , :body , :author # See CFSync.Entry.Extractors for extract_* documentation def new ( data ) do % __MODULE__ { name : extract_binary ( data , &quot;name&quot; ) , body : extract_richtext ( data , &quot;body&quot; ) , author : extract_link ( data , &quot;author&quot; ) , } end end # Define a mapping to map Contentful &quot;contentType&quot; ids to an atom name and a fields struct: content_types = %{ # &quot;page&quot; key is the content_type ID as configured in Contentful &quot;page&quot; =&gt; %{ content_type : :page , fields_module : MyApp.PageFields , } , &quot;author&quot; =&gt; %{ content_type : :author , fields_module : MyApp.AuthorFields , } # ... } # Define your locales (optional): locales = %{ en : &quot;en-US&quot; , fr : &quot;fr-FR&quot; } # If you have a single locale, but it is not &quot;en-US&quot;, you can use: # locales = %{nil: &quot;fr-FR&quot;} # Start a CFSync process { :ok , pid } = CFSync . start_link ( name : MyApp.MyCFSync , space_id : &quot;Your_contentful_space_id&quot; , delivery_token : &quot;Your_contentful_delivery_api_token&quot; , content_types : content_types , locales : locales ) # Use it store = CFSync . from ( MyApp.MyCFSync ) entry = CFSync . get_entry ( store , &quot;entry_id&quot; ) # OR, with multiple locales: # entry_fr = CFSync.get_entry(store, &quot;entry_id&quot;, :fr) # entry_en = CFSync.get_entry(store, &quot;entry_id&quot;, :en) # entry -&gt; % CFSync.Entry { id : &quot;entry_id&quot; , content_type : :page , space_id : &quot;your_space_id&quot; , fields : % MyApp.PageFields { name : &quot;Lorem ipsum&quot; , body : % CFSync.RichText { #... }, author : % CFSync.Link { id : &quot;autor_id&quot; , #... }, # ... } } author = CFSync . get_link_target ( entry . fields . author ) # Or # author = CFSync.get_child(entry, :author) # author -&gt; % CFSync.Entry { id : &quot;author_id&quot; , content_type : :author , fields : % MyApp.AuthorFields { # ... } } !! Put your API token and space_id in your ENV, NOT in your code. You should start the CFSync process in a supervision tree .","ref":"CFSync.html"},{"type":"function","title":"CFSync.force_sync/1","doc":"Forces the store for name to sync immediately. Use the name you provided to start_link/4 . CFSync regularly synces entries from Contentful API (see start_link/4 ). Calling this function triggers an immediate sync and resets the timer for the next regular sync, so it will only happen after the full delay ( :delta_sync_interval ) counting from the immediate sync. You can use Contentful publish and unpublish webhooks to trigger calls to this function in order to achieve almost instant synchronisation. You can then relax :delta_sync_interval in the configuration to lower the number of API requests made to Contentful. CFSync . force_sync ( MyApp.MyCFSync )","ref":"CFSync.html#force_sync/1"},{"type":"function","title":"CFSync.from/1","doc":"Get the CFSync store for name . Use the name you provided to start_link/4 . store = CFSync . from ( MyApp.MyCFSync ) get_entries ( store ) get_entry ( store , &quot;an_entry_id&quot; ) # ...","ref":"CFSync.html#from/1"},{"type":"function","title":"CFSync.get_asset/3","doc":"Get the asset specified by id for the given locale from the CFSync store store . Returns nil if the asset is not found. See get_entries/1 about locale.","ref":"CFSync.html#get_asset/3"},{"type":"function","title":"CFSync.get_assets/2","doc":"Returns a list containg all assets from the CFSync store store . See get_entries/1 about performance and locale.","ref":"CFSync.html#get_assets/2"},{"type":"function","title":"CFSync.get_child/2","doc":"Resolves a link (child entry or asset) from an entry field and returns the corresponding asset or entry. Returns nil if the child entry or asset is not found.","ref":"CFSync.html#get_child/2"},{"type":"function","title":"CFSync.get_children/2","doc":"Resolves a list of link (children entries or assets) from an entry field and returns the corresponding assets or entries. Returns the list of links mapped to the corresponding assets or entries. If an entry or asset is not found, it is not included in the result.","ref":"CFSync.html#get_children/2"},{"type":"function","title":"CFSync.get_entries/2","doc":"Returns a list containg all entries for a given locale from the CFSync store store . The locale is optional and defaults to nil . By default, CFSync is configured to work with a single locale (the nil locale), which is en-US . You can change the default locale by passing locales: %{nil: &quot;fr-FR&quot;} to start_link/1 . If you have multiple locales, you must pass the locale to this function to get entries for that locale. This function will retrieve ALL entries currently stored in the store's ETS table and deep copy them to the current process. Using this on a large Contentful space will be slow. If you want to retrieve all the entries to filter them, consider using something like memoize to cache the results.","ref":"CFSync.html#get_entries/2"},{"type":"function","title":"CFSync.get_entries_for_content_type/3","doc":"Returns a list containg all entries of specified content_type for a given locale from the CFSync store store . See get_entries/1 about performance and locale.","ref":"CFSync.html#get_entries_for_content_type/3"},{"type":"function","title":"CFSync.get_entry/3","doc":"Get the entry specified by id for the given locale from the CFSync store store . Returns nil if the entry is not found. See get_entries/1 about locale.","ref":"CFSync.html#get_entry/3"},{"type":"function","title":"CFSync.get_link_target/1","doc":"Resolves link in the CFSync store store and returns the corresponding asset or entry. Returns nil if link target is not found. Returns nil if link is not a CFSync.Link struct.","ref":"CFSync.html#get_link_target/1"},{"type":"function","title":"CFSync.rich_text/1","doc":"Phoenix.Component that renders RichText. You can pass these assigns: content: the %RichText{} struct to render class: a class attribute that will be added to root element of rendered HTML delegate: a module with custom components to use for rendering Delegate and class are optional. To use delegate module, see RichTextRenderer and RichTextRendererTest modules","ref":"CFSync.html#rich_text/1"},{"type":"function","title":"CFSync.start_link/1","doc":"Starts CFSync GenServer Should be started in a supervision tree Options name (required) is an atom to reference this CFSync process. Use the same name in from/1 to query entries. space_id (required) is your Contentful space's ID delivery_token (required) is your Contentful API token content_types (required) is a map describing how to map Contentful entries to elixir structs. See module doc. locales (optional) is a map of locales. The key is the locale name in Elixir (an atom), the value is the locale name in Contentful. :root_url (optional) - Default is &quot;https://cdn.contentful.com/&quot; :initial_sync_interval (optional) - The server will wait for this interval between two page requests during initial sync. Defaults to 30 milliseconds. :delta_sync_interval (optional) - The server will wait for this interval between two sync requests. Defaults to 5000 milliseconds. You can use a shorter delay to get updates faster, but you will be rate limited by Contentful if you set it too short. :invalidation_callbacks (optional) - List of 0-arity anonymous functions that will be called after each sync operation that actually adds, updates or deletes some entries.","ref":"CFSync.html#start_link/1"},{"type":"type","title":"CFSync.store/0","doc":"Reference to a CFSync store.","ref":"CFSync.html#t:store/0"},{"type":"module","title":"CFSync.Asset","doc":"The Asset struct holds data from Contentful assets. It's provided as is and is not configurable, so if you need more fields than those currently mapped, feel free to send a PR.","ref":"CFSync.Asset.html"},{"type":"type","title":"CFSync.Asset.t/0","doc":"","ref":"CFSync.Asset.html#t:t/0"},{"type":"module","title":"CFSync.Entry","doc":"The Entry struct holds standard data from Contentful entries. It's provided as is and is not configurable, so if you need more fields than those currently mapped, feel free to send a PR.","ref":"CFSync.Entry.html"},{"type":"type","title":"CFSync.Entry.t/0","doc":"","ref":"CFSync.Entry.html#t:t/0"},{"type":"module","title":"CFSync.Entry.Document","doc":"","ref":"CFSync.Entry.Document.html"},{"type":"function","title":"CFSync.Entry.Document.get_value/3","doc":"","ref":"CFSync.Entry.Document.html#get_value/3"},{"type":"module","title":"CFSync.Entry.Extractors","doc":"Utility functions to extract data from contenful JSON.","ref":"CFSync.Entry.Extractors.html"},{"type":"function","title":"CFSync.Entry.Extractors.extract_atom/4","doc":"Returns value of field_name as an atom . data is the entry's payload as provided to CFSync.Entry.Fields.new/1 field_name is the field's id in Contentful (ie. What is configured in Contentful app) mapping is a map of &quot;value&quot; =&gt; :atom used to find which atom correspond to the field's value Returns nil or default on failure (field empty, no mapping...) Options default: default value to return if the field is empty or not in the mapping force_locale: a locale to use instead of the entry's locale fallback_locale: locale to fallback to if the field is empty","ref":"CFSync.Entry.Extractors.html#extract_atom/4"},{"type":"function","title":"CFSync.Entry.Extractors.extract_binary/3","doc":"Returns value of field_name as a binary . data is the entry's payload as provided to CFSync.Entry.Fields.new/1 field_name is the field's id in Contentful (ie. What is configured in Contentful app) Returns nil or default on failure (field empty, not a string...) Options default: default value to return if the field is empty or not a binary force_locale: a locale to use instead of the entry's locale fallback_locale: locale to fallback to if the field is empty","ref":"CFSync.Entry.Extractors.html#extract_binary/3"},{"type":"function","title":"CFSync.Entry.Extractors.extract_boolean/3","doc":"Returns value of field_name as a boolean . data is the entry's payload as provided to CFSync.Entry.Fields.new/1 field_name is the field's id in Contentful (ie. What is configured in Contentful app) Returns nil or default on failure (field empty, not a boolean...) Options default: default value to return if the field is empty or not a boolean force_locale: a locale to use instead of the entry's locale fallback_locale: locale to fallback to if the field is empty","ref":"CFSync.Entry.Extractors.html#extract_boolean/3"},{"type":"function","title":"CFSync.Entry.Extractors.extract_custom/4","doc":"Returns value of field_name processed by fun . data is the entry's payload as provided to CFSync.Entry.Fields.new/1 field_name is the field's id in Contentful (ie. What is configured in Contentful app) fun is a function of arity 1 Returns nil if the field is not included in the payload. Options force_locale: a locale to use instead of the entry's locale fallback_locale: locale to fallback to if the field is empty","ref":"CFSync.Entry.Extractors.html#extract_custom/4"},{"type":"function","title":"CFSync.Entry.Extractors.extract_date/3","doc":"Returns value of field_name as a Date . data is the entry's payload as provided to CFSync.Entry.Fields.new/1 field_name is the field's id in Contentful (ie. What is configured in Contentful app) Returns nil or default on failure (field empty, invalid format, invalid date...) Options default: default value to return if the field is empty or not a date force_locale: a locale to use instead of the entry's locale fallback_locale: locale to fallback to if the field is empty","ref":"CFSync.Entry.Extractors.html#extract_date/3"},{"type":"function","title":"CFSync.Entry.Extractors.extract_datetime/3","doc":"Returns value of field_name as a DateTime . data is the entry's payload as provided to CFSync.Entry.Fields.new/1 field_name is the field's id in Contentful (ie. What is configured in Contentful app) Returns nil or default on failure (field empty, invalid format, invalid datetime...) Options default: default value to return if the field is empty or not a datetime force_locale: a locale to use instead of the entry's locale fallback_locale: locale to fallback to if the field is empty","ref":"CFSync.Entry.Extractors.html#extract_datetime/3"},{"type":"function","title":"CFSync.Entry.Extractors.extract_link/3","doc":"Returns value of field_name as a CFSync.Link . data is the entry's payload as provided to CFSync.Entry.Fields.new/1 field_name is the field's id in Contentful (ie. What is configured in Contentful app) Returns nil or default on failure (field empty, not a link...) Options default: default value to return if the field is empty or not a link force_locale: a locale to use instead of the entry's locale fallback_locale: locale to fallback to if the field is empty","ref":"CFSync.Entry.Extractors.html#extract_link/3"},{"type":"function","title":"CFSync.Entry.Extractors.extract_links/3","doc":"Returns value of field_name as a list of CFSync.Link . data is the entry's payload as provided to CFSync.Entry.Fields.new/1 field_name is the field's id in Contentful (ie. What is configured in Contentful app) Returns nil or default on failure (field empty, not a list...) Options default: default value to return if the field is empty or not a list force_locale: a locale to use instead of the entry's locale fallback_locale: locale to fallback to if the field is empty","ref":"CFSync.Entry.Extractors.html#extract_links/3"},{"type":"function","title":"CFSync.Entry.Extractors.extract_list/3","doc":"Returns value of field_name as a list . data is the entry's payload as provided to CFSync.Entry.Fields.new/1 field_name is the field's id in Contentful (ie. What is configured in Contentful app) Returns nil or default on failure (field empty, not a list...) Options default: default value to return if the field is empty or not a list force_locale: a locale to use instead of the entry's locale fallback_locale: locale to fallback to if the field is empty","ref":"CFSync.Entry.Extractors.html#extract_list/3"},{"type":"function","title":"CFSync.Entry.Extractors.extract_map/3","doc":"Returns value of field_name as a map . data is the entry's payload as provided to CFSync.Entry.Fields.new/1 field_name is the field's id in Contentful (ie. What is configured in Contentful app) Returns nil or default on failure (field empty, not a map...) Options default: default value to return if the field is empty or not a map force_locale: a locale to use instead of the entry's locale fallback_locale: locale to fallback to if the field is empty","ref":"CFSync.Entry.Extractors.html#extract_map/3"},{"type":"function","title":"CFSync.Entry.Extractors.extract_number/3","doc":"Returns value of field_name as a number . data is the entry's payload as provided to CFSync.Entry.Fields.new/1 field_name is the field's id in Contentful (ie. What is configured in Contentful app) Be careful with the result as it can be either an integer or float, depending of it's value. A contentful decimal value of 1.0 will be stored as 1 in the JSON and read as an integer by JASON. Returns nil or default on failure (field empty, not a number...) Options default: default value to return if the field is empty or not a number force_locale: a locale to use instead of the entry's locale fallback_locale: locale to fallback to if the field is empty","ref":"CFSync.Entry.Extractors.html#extract_number/3"},{"type":"function","title":"CFSync.Entry.Extractors.extract_rich_text/3","doc":"Returns value of field_name as CFSync.RichText tree. data is the entry's payload as provided to CFSync.Entry.Fields.new/1 field_name is the field's id in Contentful (ie. What is configured in Contentful app) Returns nil or default on failure (field empty, not a richtext...) Options default: default value to return if the field is empty or not a richtext force_locale: a locale to use instead of the entry's locale fallback_locale: locale to fallback to if the field is empty","ref":"CFSync.Entry.Extractors.html#extract_rich_text/3"},{"type":"type","title":"CFSync.Entry.Extractors.data/0","doc":"Entry's payload as provided to CFSync.Entry.Fields.new/1","ref":"CFSync.Entry.Extractors.html#t:data/0"},{"type":"behaviour","title":"CFSync.Entry.Fields","doc":"behaviour for fields struct. For each Contentful content-type you want to map in your Elixir app, you have to provide an Elixir module implementing this behaviour.","ref":"CFSync.Entry.Fields.html"},{"type":"callback","title":"CFSync.Entry.Fields.new/1","doc":"Called at struct creation. When creating an entry, CFSync will call this function with entry's data as first argument. Your implementation must return a struct implementing the CFSync.Entry.Fields protocol. The struct must be build using the extract_* functions provided by CFSync.Entry.Extractors You must configure your fields struct in config.exs, see CFSync . Example defmodule MyApp.PageFields do alias CFSync.Entry @behaviour Entry.Fields import Entry.Extractors defstruct :name , :body , :author def new ( data ) do % __MODULE__ { # field_name: extract_*(data, &quot;fieldNameInContentful&quot;, default: default_value) name : extract_binary ( data , &quot;name&quot; , default : &quot;Default name&quot; ) , body : extract_richtext ( data , &quot;body&quot; ) , author : extract_link ( data , &quot;author&quot; ) , } end end","ref":"CFSync.Entry.Fields.html#c:new/1"},{"type":"type","title":"CFSync.Entry.Fields.t/0","doc":"","ref":"CFSync.Entry.Fields.html#t:t/0"},{"type":"module","title":"CFSync.Link","doc":"The Link struct holds data from Contentful links. It's provided as is and is not configurable, so if you need more fields than those currently mapped, feel free to send a PR. Links are used in Contentful for relations. A single-entry or single-asset relation field will contain a Link struct (or nil ). Multi-entry and multi-asset relation fields contain a list of Link structs (or [] ). Links can be resolved through CFSync.get_link_target/1 .","ref":"CFSync.Link.html"},{"type":"function","title":"CFSync.Link.new/3","doc":"","ref":"CFSync.Link.html#new/3"},{"type":"type","title":"CFSync.Link.t/0","doc":"","ref":"CFSync.Link.html#t:t/0"},{"type":"module","title":"CFSync.RichText","doc":"RichText recursive struct RichText in Contentful is implemented as a tree of nodes. All nodes share a common structure and some of them have specific properties. Here I chosed to represent all nodes with a single struct for simplicity.","ref":"CFSync.RichText.html"},{"type":"function","title":"CFSync.RichText.map/2","doc":"Maps nodes recursively using the provided function. The provided function should accept a node and return a new node.","ref":"CFSync.RichText.html#map/2"},{"type":"function","title":"CFSync.RichText.new/1","doc":"","ref":"CFSync.RichText.html#new/1"},{"type":"function","title":"CFSync.RichText.new/3","doc":"","ref":"CFSync.RichText.html#new/3"},{"type":"type","title":"CFSync.RichText.marks/0","doc":"","ref":"CFSync.RichText.html#t:marks/0"},{"type":"type","title":"CFSync.RichText.node_types/0","doc":"","ref":"CFSync.RichText.html#t:node_types/0"},{"type":"type","title":"CFSync.RichText.t/0","doc":"","ref":"CFSync.RichText.html#t:t/0"},{"type":"module","title":"CFSync.RichTextRenderer","doc":"Phoenix components for CFSync RichText rendering. BEWARE OF WHITESPACE It is essential to avoid adding whitespace to the text content. We use white-space: pre-line; to render line breaks added to rich text. Adding line breaks here in the markup would propagate blank lines to the pages.","ref":"CFSync.RichTextRenderer.html"},{"type":"function","title":"CFSync.RichTextRenderer.render/1","doc":"","ref":"CFSync.RichTextRenderer.html#render/1"},{"type":"task","title":"Mix.Tasks.CfSync.Dump","doc":"This task downloads the contentful entries and assets to a local file for dev purposes.","ref":"Mix.Tasks.CfSync.Dump.html"},{"type":"task","title":"Mix.Tasks.CfSync.Setup","doc":"This task builds config files for use with mix cf_sync.dump .","ref":"Mix.Tasks.CfSync.Setup.html"}]